@@ -1,5 +1,5 @@
 package Tangerine::Utils;
-$Tangerine::Utils::VERSION = '0.20';
+$Tangerine::Utils::VERSION = '0.21';
 use 5.010;
 use strict;
 use warnings;
@@ -30,7 +30,7 @@ sub stripquotelike {
         } grep {
             1 if !/^(?:,|=>|;|)$/so
         } map {
-            s/^\s+|\s+$//sgor
+            (my $trim = $_) =~ s/^\s+|\s+$//sgo; $trim
         } @_;
     return wantarray ? @filtered : $filtered[0];
 }
